
%global pkg_name hashtables
%global pkgver %{pkg_name}-%{version}


Name:           ghc-%{pkg_name}
Version:        1.3.1
Release:    1%{?dist}
Summary:        Mutable hash tables in the ST monad

License:        BSD-3-Clause
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkgver}/%{pkgver}.tar.gz

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-vector-devel
%if %{with ghc_prof}
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-primitive-prof
BuildRequires:  ghc-vector-prof
%endif

%description
This package provides a couple of different implementations of mutable
hash tables in the ST monad, as well as a typeclass abstracting their
common operations, and a set of wrappers to use the hash tables in the
IO monad.

This package currently contains three hash table implementations:

1. Data.HashTable.ST.Basic contains a basic open-addressing hash table
using linear probing as the collision strategy.

2. Data.HashTable.ST.Cuckoo contains an implementation of "cuckoo hashing"
which has worst-case O(1) lookups and can reach a high "load factor".

3. Data.HashTable.ST.Linear contains a linear hash table, which trades
some insert and lookup performance for higher space efficiency and
much shorter delays when expanding the table.


%package devel
Summary:        Haskell %{pkg_name} library development files
Provides:       %{name}-static = %{version}-%{release}
Provides:       %{name}-static = %{version}-%{release}
%if %{defined ghc_version}
Requires:       ghc-compiler = %{ghc_version}
%endif
Requires:       %{name} = %{version}-%{release}

%description devel
This package provides the Haskell %{pkg_name} library development files.
2. "Data.HashTable.ST.Basic" contains a basic open-addressing hash table using
linear probing as the collision strategy. On a pure speed basis it should
currently be the fastest available Haskell hash table implementation for
lookups, although it has a higher memory overhead than the other tables and can
suffer from long delays when the table is resized because all of the elements
in the table need to be rehashed.



%if %{with haddock}
%package doc
Summary:        Haskell %{pkg_name} library documentation
BuildArch:      noarch
Requires:       ghc-filesystem

%description doc
This package provides the Haskell %{pkg_name} library documentation.
%endif


%if %{with ghc_prof}
%package prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       %{name}-devel = %{version}-%{release}
Supplements:    (%{name}-devel and ghc-prof)

%description prof
This package provides the Haskell %{pkg_name} profiling library.
%endif


%prep
%setup -q -n %{pkgver}


%build
%ghc_lib_build


%install
%ghc_lib_install


%files -f %{name}.files
%license LICENSE


%files devel -f %{name}-devel.files
%doc README.md changelog.md


%if %{with haddock}
%files doc -f %{name}-doc.files
%license LICENSE
%endif


%if %{with ghc_prof}
%files prof -f %{name}-prof.files
%endif


%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.1-1
- initial build
